Change CPLD clear cmos command register is changed to 0x61

New CPLD FW changed this register to 0x61

Tested:
Run the below command in MFG mode,
the system will restart and perform the clear CMOS action:
ipmitoo raw 0x32 0x91

Signed-off-by: Yong Li <yong.b.li@linux.intel.com>
Change-Id: I859804a09f71d50bb4b7066497e195165f9b4f6e
diff --git a/src/manufacturingcommands.cpp b/src/manufacturingcommands.cpp
index c554afa..6fed043 100644
--- a/src/manufacturingcommands.cpp
+++ b/src/manufacturingcommands.cpp
@@ -962,11 +962,11 @@
 ipmi::RspType<> clearCMOS()
 {
     // There is an i2c device on bus 4, the slave address is 0x38. Based on the
     // spec, writing 0x1 to address 0x60 on this device, will trigger the clear
     // CMOS action.
     constexpr uint8_t slaveAddr = 0x38;
     std::string i2cBus = "/dev/i2c-4";
-    std::vector<uint8_t> writeData = {0x60, 0x1};
+    std::vector<uint8_t> writeData = {0x61, 0x1};
     std::vector<uint8_t> readBuf(0);
 
     if (mtm.getMfgMode() == SpecialMode::none)
@@ -962,11 +962,11 @@
 {
     // There is an i2c device on bus 4, the slave address is 0x38. Based on the
-    // spec, writing 0x1 to address 0x60 on this device, will trigger the clear
+    // spec, writing 0x1 to address 0x61 on this device, will trigger the clear
     // CMOS action.
     constexpr uint8_t slaveAddr = 0x38;